@@ -19,19 +19,20 @@
 #include <fcntl.h>
 #include <math.h>
 #include <time.h>
+#ifdef USE_MCHECK
 #include <mcheck.h>
+#endif
 
 #include <gtk/gtk.h>
 #include <gdk/gdk.h>
 
 #include <gpe/init.h>
 #include <gpe/errorbox.h>
-#include <gpe/render.h>
 #include <gpe/pixmaps.h>
 #include <gpe/picturebutton.h>
 #include <gpe/question.h>
 #include <gpe/dirbrowser.h>
-#include <gpe/gpe-iconlist.h>
+#include <gpe/gpeiconlistview.h>
 #include <gpe/spacing.h>
 
 #include "image_tools.h"
@@ -732,7 +733,7 @@ render_icon_view ()
   GList *this_item;
   gchar *image_filename, *buf;
 
-  il = gpe_iconlist_new ();
+  il = gpe_icon_list_view_new ();
 
   this_item = image_filenames;
   while (this_item)
@@ -740,7 +741,7 @@ render_icon_view ()
     image_filename = (gchar *) this_item->data;
     buf = g_strdup (image_filename);
 
-    gpe_iconlist_add_item (GPE_ICONLIST(il), basename (buf), image_filename, this_item);
+    gpe_icon_list_view_add_item (GPE_ICON_LIST_VIEW(il), basename (buf), image_filename, this_item);
 
     gtk_progress_bar_pulse (GTK_PROGRESS_BAR (loading_progress_bar));
 
@@ -1025,7 +1026,6 @@ toggle_fullscreen ()
 
     gtk_widget_reparent (main_scrolled_window, fullscreen_window);
 
-//    gtk_widget_set_size_request (fullscreen_window, gdk_screen_width (), gdk_screen_height ());
     gtk_widget_show_all (fullscreen_window);
 
     gdk_window_fullscreen (GDK_WINDOW (fullscreen_window->window));
@@ -1111,11 +1111,11 @@ main (int argc, char *argv[])
 {
   GtkWidget *vbox, *scrolled_window, *toolbar, *loading_label, *toolbar_icon;
   GdkPixbuf *p;
-  GdkPixmap *pmap;
-  GdkBitmap *bmap;
   struct stat arg_stat;
 
+#ifdef USE_MCHECK
   mtrace ();
+#endif
 
   if (gpe_application_init (&argc, &argv) == FALSE)
     exit (1);
@@ -1141,7 +1141,6 @@ main (int argc, char *argv[])
 
   scrolled_window = gtk_scrolled_window_new (NULL, NULL);
   main_scrolled_window = scrolled_window;
-//  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window), GTK_POLICY_NEVER, GTK_POLICY_NEVER);
 
   image_widget = gtk_image_new_from_pixbuf (image_pixbuf);
   image_event_box = gtk_event_box_new ();
@@ -1270,9 +1269,8 @@ main (int argc, char *argv[])
   gtk_box_pack_start (GTK_BOX (vbox), loading_toolbar, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), tools_toolbar, FALSE, FALSE, 0);
 
-  if (gpe_find_icon_pixmap ("icon", &pmap, &bmap))
-    gdk_window_set_icon (window->window, NULL, pmap, bmap);
-
+  gtk_window_set_icon(GTK_WINDOW(window), gpe_find_icon("icon"));
+  
   gtk_widget_show (window);
   gtk_widget_show (vbox);
   gtk_widget_show (vbox2);
